<template>
    <div class="bbsl-common-page">
        <div class="bbsl-table-search">
            <el-form label-width="auto">
                <el-row :gutter="10">
                    <el-col :span="5">
                        <el-form-item label="排班部门" prop="org">
                            <el-cascader v-model="org" :options="orgList" placeholder="请选择排班部门"
                                :props="{
                                    expandTrigger: 'hover',
                                    value: 'id',
                                    label: 'name',
                                    leaf: 'leaf',
                                }" @change="selectChange" />
                        </el-form-item>
                    </el-col>
                    <el-col :span="5">
                        <el-form-item label="班种">
                            <el-select v-model="workclassId" clearable size="small"
                                placeholder="请选择班种">
                                <!-- @change="selectChange" -->
                                <el-option v-for="item in classInfos" :key="item.id" :label="item.name +
                                    '（' +
                                    item.scheduleStart +
                                    ' - ' +
                                    item.duringTime +
                                    '）'
                                    " :value="item.id" />
                            </el-select>
                        </el-form-item>
                    </el-col>
                    <el-col :span="5">
                        <el-form-item label="日期">
                            <el-date-picker v-model="date" :clearable="false" value-format="yyyy-MM-dd" type="month"
                                placeholder="选择日期"></el-date-picker>
                        </el-form-item>
                    </el-col>
                    <el-col :span="6">
                        <el-button type="primary" icon="el-icon-search" @click="searchHandel">搜索</el-button>
                        <el-button icon="el-icon-refresh" @click="handleReset">重置</el-button>
                        <el-button type="warning" icon="el-icon-download" @click="downFile"
                            :disabled="!date || !orgId">导出</el-button>
                    </el-col>
                </el-row>


                <!-- <el-form-item label="小组名称" prop="teamId">
          <el-select v-model="teamId" clearable style="width:100%" size="small" placeholder="请选择小组">
            <el-option v-for="item in teams" :key="item.id" :label="item.name" :value="item.id" />
          </el-select>
        </el-form-item> -->
            </el-form>
        </div>
        <div class="bbsl-table-content">
            <el-tabs v-model="activeName" @tab-click="handleClick">
                <el-tab-pane label="人员排班表" name="人员排班表">
                    <el-table border size="mini" v-loading="loading" :data="userTableData" :style="{ width: '100%' }"
                        :cell-style="{ 'text-align': 'center' }" :header-cell-style="{ 'text-align': 'center' }"
                        height="calc(100% - 20px)" class="user-table">
                        <el-table-column v-for="(item, index) in Object.keys(
                            userTableHeader
                        )" :key="index" :prop="item" :label="userTableHeader[item]" :min-width="index == 0 ? 70 : 39"
                            show-overflow-tooltip>
                            <template #header>
                                <span class="header-pre" :class="userTableHeader[item].indexOf('六') !==
                                    -1 ||
                                    userTableHeader[item].indexOf('日') !==
                                    -1
                                    ? 'zm'
                                    : ''
                                    ">
                                    {{ userTableHeader[item] }}
                                </span>
                            </template>
                            <template slot-scope="scope">
                                <span v-if="item === 'memberName'">{{
                                    scope.row[item]
                                }}</span>
                                <i class="el-icon-check" v-else-if="
                                    item !== 'memberName' &&
                                    scope.row[item] &&
                                    scope.row[item] === 'T'
                                "></i>
                                <span v-else-if="
                                    item !== 'memberName' &&
                                    scope.row[item] &&
                                    scope.row[item] !== 'T'
                                ">{{ scope.row[item] }}
                                </span>
                            </template>
                        </el-table-column>
                    </el-table>
                </el-tab-pane>
                <el-tab-pane label="日期排班表" name="日期排班表">
                    <el-table border size="mini" v-loading="loading" :data="dateTableData" :style="{ width: '100%' }"
                        :cell-style="{ 'text-align': 'left' }" :header-cell-style="{ 'text-align': 'center' }"
                        height="calc(100% - 20px)">
                        <el-table-column v-for="(item, index) in Object.keys(
                            dateTableHeader
                        )" :key="index" :prop="item" :label="dateTableHeader[item]" :width="countWidthHandel(item)">
                            <!-- <template slot-scope="scope">
                            <span v-if="item === 'date' || item === 'groupLeader'">{{scope.row[item]}}</span>
                            <template v-if="item === 'workClass'">
                            <div
                                class="work-class"
                                v-for="(it,ind) in scope.row.workClass"
                                :key="ind"
                            >{{it.workClassName}}</div>
                            </template>
                            <div v-if="item === 'memberInfo'">
                            <div
                                class="member-class"
                                v-for="(it,ind) in scope.row.workClass"
                                :key="ind"
                                :title="it.memberInfo"
                            >{{it.memberInfo}}</div>
                            <div class="member-class" v-for="(it,ind) in scope.row.workClass" :key="ind">
                                <div v-for="(res,num) in it.memberInfo.split(' ')" :key="num">{{res}}</div>
                            </div>
                            </div>
                        </template> -->
                        </el-table-column>
                    </el-table>
                </el-tab-pane>
            </el-tabs>
        </div>
    </div>
</template>

<script>
import CmgtDutyWorkarrangeApi from '@/views/Manage/duty/api/CmgtDutyWorkarrangeApi'
import CommonApi from '@/views/Manage/CommonApi.js'
import { TableMixin } from '@/mixins/tableMixin'
import { mapState } from 'vuex'
import moment from 'moment'
export default {
    name: 'SchedulingInquire', // 排班查询
    components: {},
    mixins: [TableMixin],
    data() {
        return {
            activeName: '人员排班表',
            orgList: [], // 组织信息列表
            org: '', // 所选组织
            orgId: '', // 所选组织id
            workclassId: null, // 班种id
            classInfos: [], // 班种列表
            teamId: '', // 小组id
            teams: [], // 小组列表
            date: '', // 排班日期
            userTableData: [], // 人员值班表列表数据
            userTableHeader: {}, // 人员值班表表头数据
            dateTableData: [], // 日期值班表表列表数据
            dateTableHeader: {}, // 日期值班表表头数据
            rules: {
                org: [
                    {
                        required: true,
                        message: '请选排班部门',
                        trigger: 'blur',
                    },
                ],
                teamId: [
                    {
                        required: true,
                        message: '请选小组名称',
                        trigger: 'blur',
                    },
                ],
            },
        }
    },

    created() {
        this.getOrgList()
        this.date = moment().format('YYYY-MM-' + '01')
    },
    computed: mapState({
        userInfo: (state) => {
            return state.user
        },
    }),
    mounted() {
        setTimeout(() => {
            // this.orgId = this.userInfo.currentUserDetail.org[0].orgId
            CmgtDutyWorkarrangeApi.getUserOrganization(
                this.userInfo.currentUserDetail.user.userId,
                (res) => {
                    let info = res[0].path.split('.').slice(0, -1)
                    this.org = info
                    // this.selectChange()
                }
            )
        }, 1000)
    },
    methods: {
        handleReset() {
            this.date = moment().format('YYYY-MM-' + '01')
            this.org = ''
            this.workclassId = ''
            this.getTimeTableData()
        },
        // 获取组织列表
        getOrgList() {
            CommonApi.getArrangeOrgTree((res) => {
                this.setLeaf(res.data)
                this.orgList = res.data
            })
            // CommonApi.getAllOrgTree((res) => {
            //     this.setLeaf(res.data)
            //     this.orgList = res.data
            // })
        },
        setLeaf(orgs) {
            const count = orgs.length
            for (var i = 0; i < count; i++) {
                var org = orgs[i]
                if (org.children && org.children.length > 0) {
                    org.leaf = false
                    this.setLeaf(org.children)
                } else {
                    org.leaf = true
                    org.children = null
                }
            }
        },
        loadData() { },
        getData() {
            this.loading = true
            this.getUserTableData()
            this.getTimeTableData()
        },
        // 获取日期排班表数据
        getTimeTableData() {
            this.dateTableData = []
            this.dateTableHeader = []
            CmgtDutyWorkarrangeApi.findTeamWorkClass(
                {
                    date: this.date,
                    orgId: this.orgId,
                    workclassId: this.workclassId,
                },
                (res) => {
                    this.loading = false
                    let list = res.value
                    if (list.length) {
                        this.dateTableHeader = list[0]
                        this.dateTableData = list.splice(1)
                    }
                }
            )
        },
        // 获取人员排班表数据
        getUserTableData() {
            this.userTableHeader = []
            this.userTableData = []
            CmgtDutyWorkarrangeApi.findTeamMemberList(
                {
                    date: this.date,
                    orgId: this.orgId,
                    workclassId: this.workclassId,
                },
                (res) => {
                    this.loading = false
                    let list = res.value
                    if (list.length) {
                        this.userTableHeader = list[0]
                        this.userTableData = list.splice(1)
                    }
                }
            )
        },
        findTeam(orgId) {
            CmgtDutyWorkarrangeApi.findTeam(orgId, (res) => {
                if (res.state) {
                    this.teams = res.value
                }
            })
        },
        findClass(orgId) {
            CmgtDutyWorkarrangeApi.findClass(orgId, (res) => {
                if (res.state) {
                    this.classInfos = res.value
                }
            })
        },
        selectChange() {
            var v = { value: this.org[this.org.length - 1] }
            this.orgId = v.value
            this.templateName = v.template
            // 选择部门排班表后，获取该部门的小组和队员信息
            var query = {
                querys: [
                    {
                        group: 'main',
                        operation: 'EQUAL',
                        parentGroup: '',
                        property: 'org_id_',
                        relation: 'AND',
                        value: v.value,
                    },
                ],
            }
            // this.findTeam({
            //     ...query,
            //     sorter: [{direction: 'ASC', property: 'sn_'}]
            // })
            this.findClass(query)
        },
        handleClick(tab, event) { },
        // 搜索
        searchHandel() {
            // if (!this.teamId) {
            //     return this.$message({
            //         message: '请选择"小组名称"后进行查询',
            //         type: 'warning'
            //     })
            // }
            this.getData()
        },
        // 动态计算宽度
        countWidthHandel(label) {
            let width = ''
            switch (label) {
                case 'date':
                    width = 120
                    break
                case 'headMan':
                    width = 160
                    break
                case 'ledCaptain':
                    width = 160
                    break
                case 'workClassName':
                    width = 180
                    break
                case 'groupLeader':
                    width = 160
                    break

                default:
            }
            return width
        },
        // 导出值班表
        downFile() {
            // CmgtDutyWorkarrangeApi
            if (this.activeName === '人员排班表') {
                CmgtDutyWorkarrangeApi.workClassExportList(
                    {
                        date: this.date,
                        orgId: this.orgId,
                    },
                    () => { }
                )
            } else if (this.activeName === '日期排班表') {
                CmgtDutyWorkarrangeApi.workClassExportAll(
                    {
                        date: this.date,
                        orgId: this.orgId,
                    },
                    () => { }
                )
            }
        },
    },
}
</script>
<style lang="scss" scoped>
.type-tag {
    margin: 0 2px;
}

::v-deep.el-tab-pane {
    width: 100%;
    height: calc(100% - 20px);
}

::v-deep .el-table__row {
    .el-table__cell {
        border-right: 1px solid #ebeef5 !important;
    }
}

::v-deep .el-table__header {
    .el-table__cell {
        border-right: 1px solid #ebeef5 !important;
    }
}

::v-deep .cell {

    // padding: 0px !important;
    .work-class {
        display: flex;
        align-items: center;
        justify-content: center;
        min-height: 50px;

        &:nth-child(2n) {
            border-top: 1px solid rgb(229, 232, 240);
        }
    }

    .member-class {
        display: flex;
        flex-direction: column;
        align-items: center;
        justify-content: center;
        min-height: 50px;

        div {
            min-height: 25px;
            // &:nth-child(2n) {
            //   padding: 3px 0px 0px 0px;
            // }
        }

        &:nth-child(2n) {
            border-top: 1px solid rgb(229, 232, 240);
        }
    }
}

::v-deep .el-table--mini .el-table__cell {
    padding: 0px !important;
}

::v-deep .user-table.el-table th {
    height: 20px !important;
}

::v-deep .user-table.el-table th.el-table__cell>.cell {
    display: inline-block;
    width: 100%;
    box-sizing: border-box;
    position: relative;
    vertical-align: middle;
    padding-left: 0;
    padding-right: 0;
    width: auto;
    line-height: initial;
    overflow: hidden;
}

.header-pre {
    width: 100%;
    height: 60px !important;
    white-space: pre-wrap;
    line-height: initial;
    text-align: center;
    display: inline-block;
    position: relative;
    vertical-align: middle;
    box-sizing: border-box;
    display: flex;
    justify-content: center;
    align-items: center;
    margin-top: -10px;
    padding-bottom: 10px;
}

.zm {
    background-color: #dae4ff;
}
</style>